Defines the MultiSet type.
Structs
- Multi
Set - A set that allows duplicate elements. The set is implemented as a map from elements to their counts. However, the API is designed to be more like a set, including the ability to iterate over duplicate elements multiple times.